RtosTrace

Trait RtosTrace 

pub trait RtosTrace {
Show 18 methods // Required methods fn start(); fn stop(); fn task_new(id: u32); fn task_send_info(id: u32, info: TaskInfo); fn task_new_stackless(id: u32, name: &'static str, priority: u32); fn task_terminate(id: u32); fn task_exec_begin(id: u32); fn task_exec_end(); fn task_ready_begin(id: u32); fn task_ready_end(id: u32); fn system_idle(); fn isr_enter(); fn isr_exit(); fn isr_exit_to_scheduler(); fn name_marker(id: u32, name: &'static str); fn marker(id: u32); fn marker_begin(id: u32); fn marker_end(id: u32);
}
Collection of tracing functions which are called by the RTOS.

Required Methods

fn start()

Start tracing.

fn stop()

Stop tracing.

fn task_new(id: u32)

A new task with id was created.

fn task_send_info(id: u32, info: TaskInfo)

The task with id has info attributes.

fn task_new_stackless(id: u32, name: &'static str, priority: u32)

Convenience function to create a new task with a name only.

fn task_terminate(id: u32)

The task with id has been terminated.

fn task_exec_begin(id: u32)

The task with id will start to run on the CPU now.

fn task_exec_end()

Execution of the current task has ended.

fn task_ready_begin(id: u32)

The task with id is ready to run.

fn task_ready_end(id: u32)

The task with id is being blocked/suspended.

fn system_idle()

The RTOS enters idle mode.

fn isr_enter()

Enter an ISR.

fn isr_exit()

Exit an ISR.

fn isr_exit_to_scheduler()

Exit an ISR to the scheduler.

fn name_marker(id: u32, name: &'static str)

Create a new marker with id.

fn marker(id: u32)

Create a new marker with id.

fn marker_begin(id: u32)

Begin event of marker with id.

fn marker_end(id: u32)

End event of marker with id.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors