pub trait RtosTrace {
Show 18 methods
// Required methods
fn start();
fn stop();
fn task_new(id: u32);
fn task_send_info(id: u32, info: TaskInfo);
fn task_new_stackless(id: u32, name: &'static str, priority: u32);
fn task_terminate(id: u32);
fn task_exec_begin(id: u32);
fn task_exec_end();
fn task_ready_begin(id: u32);
fn task_ready_end(id: u32);
fn system_idle();
fn isr_enter();
fn isr_exit();
fn isr_exit_to_scheduler();
fn name_marker(id: u32, name: &'static str);
fn marker(id: u32);
fn marker_begin(id: u32);
fn marker_end(id: u32);
}Expand description
Collection of tracing functions which are called by the RTOS.
Required Methods
Sourcefn task_send_info(id: u32, info: TaskInfo)
fn task_send_info(id: u32, info: TaskInfo)
The task with id has info attributes.
Sourcefn task_new_stackless(id: u32, name: &'static str, priority: u32)
fn task_new_stackless(id: u32, name: &'static str, priority: u32)
Convenience function to create a new task with a name only.
Sourcefn task_terminate(id: u32)
fn task_terminate(id: u32)
The task with id has been terminated.
Sourcefn task_exec_begin(id: u32)
fn task_exec_begin(id: u32)
The task with id will start to run on the CPU now.
Sourcefn task_exec_end()
fn task_exec_end()
Execution of the current task has ended.
Sourcefn task_ready_begin(id: u32)
fn task_ready_begin(id: u32)
The task with id is ready to run.
Sourcefn task_ready_end(id: u32)
fn task_ready_end(id: u32)
The task with id is being blocked/suspended.
Sourcefn system_idle()
fn system_idle()
The RTOS enters idle mode.
Sourcefn isr_exit_to_scheduler()
fn isr_exit_to_scheduler()
Exit an ISR to the scheduler.
Sourcefn name_marker(id: u32, name: &'static str)
fn name_marker(id: u32, name: &'static str)
Create a new marker with id.
Sourcefn marker_begin(id: u32)
fn marker_begin(id: u32)
Begin event of marker with id.
Sourcefn marker_end(id: u32)
fn marker_end(id: u32)
End event of marker with id.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".